DocTheme class
Theme configuration for document generation.
Allows customizing colors, branding, and footer text for different apps using neom_docs.
Constructors
Properties
- accentColor → PdfColor
-
Primary accent color
final
- accentDark → PdfColor
-
Secondary/dark accent color
final
- brandName → String
-
Brand name shown in header
final
- brandVersion → String
-
Version string shown in header
final
-
Footer text (center)
final
-
Footer text (left side)
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited